SWDEV-393199 - Added new include file for opengl interop mappings for nvidia

Change-Id: I2e955a9dd06539939188a5f2e1dde4f173af1202
Tá an tiomantas seo le fáil i:
Ioannis Assiouras
2023-04-25 18:25:10 +01:00
tuismitheoir 7f41a96ffb
tiomantas 633e720da4
D'athraigh 2 comhad le 44 breiseanna agus 19 scriosta
@@ -27,7 +27,6 @@ THE SOFTWARE.
#include <cuda.h>
#include <cuda_profiler_api.h>
#include <cuda_fp16.h>
#include <cuda_gl_interop.h>
#include <stdio.h>
@@ -1304,11 +1303,6 @@ typedef cudaExternalSemaphore_t hipExternalSemaphore_t;
typedef struct cudaExternalSemaphoreSignalParams hipExternalSemaphoreSignalParams;
typedef struct cudaExternalSemaphoreWaitParams hipExternalSemaphoreWaitParams;
typedef enum cudaGLDeviceList hipGLDeviceList;
#define hipGLDeviceListAll cudaGLDeviceListAll
#define hipGLDeviceListCurrentFrame cudaGLDeviceListCurrentFrame
#define hipGLDeviceListNextFrame cudaGLDeviceListNextFrame
typedef struct cudaGraphicsResource hipGraphicsResource;
typedef cudaGraphicsResource_t hipGraphicsResource_t;
@@ -2915,19 +2909,6 @@ inline static hipError_t hipDestroyExternalMemory(hipExternalMemory_t extMem) {
return hipCUDAErrorTohipError(cudaDestroyExternalMemory(extMem));
}
inline static hipError_t hipGLGetDevices(unsigned int* pHipDeviceCount, int* pHipDevices, unsigned int hipDeviceCount,
hipGLDeviceList deviceList) {
return hipCUDAErrorTohipError(cudaGLGetDevices(pHipDeviceCount, pHipDevices, hipDeviceCount, deviceList));
}
inline static hipError_t hipGraphicsGLRegisterBuffer(hipGraphicsResource** resource, GLuint buffer, unsigned int flags) {
return hipCUDAErrorTohipError(cudaGraphicsGLRegisterBuffer(resource, buffer, flags));
}
inline static hipError_t hipGraphicsGLRegisterImage(hipGraphicsResource** resource, GLuint image, GLenum target, unsigned int flags) {
return hipCUDAErrorTohipError(cudaGraphicsGLRegisterImage(resource, image, target, flags));
}
inline static hipError_t hipGraphicsMapResources(int count, hipGraphicsResource_t* resources, hipStream_t stream __dparm(0)) {
return hipCUDAErrorTohipError(cudaGraphicsMapResources(count, resources, stream));
}